@@ -9,9 +9,12 @@ from __future__ import annotations
 import contextlib as _contextlib
 import json as _json
 import os as _os
+import re as _re
 import shutil as _shutil
 import typing as _t
+from argparse import HelpFormatter as _HelpFormatter
 from pathlib import Path as _Path
+from subprocess import CalledProcessError as _CalledProcessError
 from tempfile import TemporaryDirectory as _TemporaryDirectory
 from types import TracebackType as _TracebackType
 
@@ -25,12 +28,14 @@ from object_colors import Color as _Color
 
 from ._version import __version__
 
-NAME = __name__.split(".", maxsplit=1)[0]
-GIT_DIR = ".git"
-INFO = 20
-WARNING = 30
-ERROR = 40
+_NAME = __name__.split(".", maxsplit=1)[0]
+_GIT_DIR = ".git"
+_INFO = 20
+_WARNING = 30
+_ERROR = 40
+_PRE_COMMIT_CONFIG = ".pre-commit-config.yaml"
 
+_git = _Git()
 _color = _Color()
 
 _color.populate_colors()
@@ -40,12 +45,16 @@ class _Parser(_ArgumentParser):
     def __init__(self) -> None:
         super().__init__(
             __version__,
-            prog=_color.cyan.get(NAME),
+            prog=_color.cyan.get(_NAME),
             description="Checkout repos to current cookiecutter config",
+            formatter_class=lambda prog: _HelpFormatter(
+                prog, max_help_position=45
+            ),
         )
         self._add_arguments()
         self.args = self.parse_args()
         self.args.repos = tuple(_Path(i) for i in self.args.repos)
+        self.args.ignore = tuple(_Path(i) for i in self.args.ignore)
 
     def _add_arguments(self) -> None:
         self.add_argument(
@@ -68,6 +77,22 @@ class _Parser(_ArgumentParser):
             action="store_true",
             help="accept pre/post hooks",
         )
+        self.add_argument(
+            "-c",
+            "--gc",
+            action="store_true",
+            help="clean up backups from previous runs",
+        )
+        self.add_list_argument(
+            "-i",
+            "--ignore",
+            action="store",
+            metavar="LIST",
+            help=(
+                "comma separated list of paths to ignore, cookiecutter vars"
+                " are allowed"
+            ),
+        )
 
 
 class _MetaData(_t.Dict[str, str]):
@@ -126,18 +151,61 @@ def temporary_directory() -> _t.Generator[_Path, None, None]:
 
 def _report(level: int, repo: _Path, message: str) -> None:
     ident = (15 - len(str(repo))) * " "
-    color = {INFO: _color.green, WARNING: _color.yellow, ERROR: _color.red}
+    color = {_INFO: _color.green, _WARNING: _color.yellow, _ERROR: _color.red}
     print(f"[{color[level].get(repo)}{ident}] {message}")
 
 
+def _garbage_collection(cache_dir: _Path) -> None:
+    if cache_dir.is_dir():
+        _report(_INFO, cache_dir, "cleaning")
+        for path in cache_dir.iterdir():
+            _shutil.rmtree(path)
+
+
+@_contextlib.contextmanager
+def _stage_pre_commit(repo: _Path) -> _t.Generator[None, None, None]:
+    path = repo / _PRE_COMMIT_CONFIG
+    if path.is_file():
+        _git.add(path.name)
+
+    yield
+    _git.reset(path.name, file=_os.devnull)
+
+
+def _revert_ignored(
+    paths: tuple[_Path, ...], repo: _Path, metadata: _MetaData
+) -> None:
+    with _ChDir(repo):
+        with _stage_pre_commit(repo):
+            for path in paths:
+                rgx = _re.match(r"{{\s?cookiecutter\.(.[^ ]*)\s?}}", str(path))
+                if rgx:
+                    new_path = metadata.get(rgx.group(1))
+                    if new_path is not None:
+                        path = _Path(new_path)
+
+                if path.exists():
+                    if path.is_dir():
+                        _shutil.rmtree(path)
+                    else:
+                        _os.remove(path)
+
+                try:
+                    _git.checkout("HEAD", "--", str(path), file=_os.devnull)
+                except _CalledProcessError:
+                    pass
+
+
 def main() -> int:
     """Main function for package.
 
     :return: Exit status.
     """
     parser = _Parser()
-    cache_dir = _Path(_appdirs.user_cache_dir(NAME))
-    git = _Git()
+    cache_dir = _Path(_appdirs.user_cache_dir(_NAME))
+    if parser.args.gc:
+        _garbage_collection(cache_dir)
+
     with temporary_directory() as temp:
         template = temp / parser.args.path.name
         _shutil.copytree(parser.args.path, template)
@@ -145,17 +213,17 @@ def main() -> int:
         defaults = _json.loads(config.read_text(encoding="utf-8"))
         for repo in parser.args.repos:
             pyproject_toml = repo / "pyproject.toml"
-            git_dir = repo / GIT_DIR
+            git_dir = repo / _GIT_DIR
             if not repo.is_dir():
-                _report(WARNING, repo, "does not exist")
+                _report(_WARNING, repo, "does not exist")
                 continue
 
             if not git_dir.is_dir():
-                _report(WARNING, repo, "not a repository")
+                _report(_WARNING, repo, "not a repository")
                 continue
 
             if not pyproject_toml.is_file():
-                _report(WARNING, repo, "missing pyproject.toml")
+                _report(_WARNING, repo, "missing pyproject.toml")
                 continue
 
             temp_repo = temp / repo.name
@@ -168,9 +236,9 @@ def main() -> int:
             metadata.setentry(repo)
             defaults.update(metadata)
             config.write_text(_json.dumps(defaults), encoding="utf-8")
-            temp_git_dir = temp_repo / GIT_DIR
+            temp_git_dir = temp_repo / _GIT_DIR
             with _ChDir(temp_repo):
-                git.stash(file=_os.devnull)
+                _git.stash(file=_os.devnull)
 
             if archived_repo.is_dir():
                 _shutil.rmtree(archived_repo)
@@ -185,10 +253,11 @@ def main() -> int:
             if temp_git_dir.is_dir():
                 _shutil.rmtree(temp_git_dir)
 
-            _shutil.copytree(archived_repo / GIT_DIR, temp_git_dir)
+            _shutil.copytree(archived_repo / _GIT_DIR, temp_git_dir)
+            _revert_ignored(parser.args.ignore, temp_repo, metadata)
             _shutil.rmtree(repo)
             _shutil.move(temp_repo, repo)
 
-            _report(INFO, repo, "success")
+            _report(_INFO, repo, "success")
 
     return 0
